@@ -34,7 +34,7 @@ class WeatherForecast:
                                self.visibility)
 
     def __str__(self):
-        return self.time.strftime("%Y.%m.%d %H:%M") + \
+        return self.time_utc.isoformat() + " (" + self.time.isoformat() + ")" + \
                ", irradiance=" + str(round(self.irradiance)) + \
                ", sunshine=" + str(round(self.sunshine)) + \
                ", cloud_cover=" + str(round(self.cloud_cover)) + \
